@@ -1,4 +1,3 @@
-# coding: utf-8
 """Jupyter LabExtension Entry Points."""
 
 # Copyright (c) Jupyter Development Team.
@@ -29,11 +28,7 @@ from .commands import (
     unlink_package,
     update_extension,
 )
-from .federated_labextensions import (
-    build_labextension,
-    develop_labextension_py,
-    watch_labextension,
-)
+from .federated_labextensions import build_labextension, develop_labextension_py, watch_labextension
 from .labapp import LabApp
 
 flags = dict(base_flags)
@@ -99,8 +94,6 @@ disable_aliases["level"] = "DisableLabExtensionsApp.level"
 
 VERSION = get_app_version()
 
-HERE = os.path.abspath(os.path.dirname(__file__))
-
 LABEXTENSION_COMMAND_WARNING = "Users should manage prebuilt extensions with package managers like pip and conda, and extension authors are encouraged to distribute their extensions as prebuilt packages"
 
 
@@ -156,7 +149,8 @@ class BaseExtensionApp(JupyterApp, DebugLogFileMixin):
 
     def start(self):
         if self.app_dir and self.app_dir.startswith(HERE):
-            raise ValueError("Cannot run lab extension commands in core app")
+            msg = "Cannot run lab extension commands in core app"
+            raise ValueError(msg)
         with self.debug_logging():
             ans = self.run_task()
             if ans and self.should_build:
@@ -213,25 +207,23 @@ class InstallLabExtensionApp(BaseExtensionApp):
         pinned_versions = self.pin.split(",")
         self.extra_args = self.extra_args or [os.getcwd()]
         return any(
-            [
-                install_extension(
-                    arg,
-                    # Pass in pinned alias if we have it
-                    pin=pinned_versions[i] if i < len(pinned_versions) else None,
-                    app_options=AppOptions(
-                        app_dir=self.app_dir,
-                        logger=self.log,
-                        core_config=self.core_config,
-                        labextensions_path=self.labextensions_path,
-                    ),
-                )
-                for i, arg in enumerate(self.extra_args)
-            ]
+            install_extension(
+                arg,
+                # Pass in pinned alias if we have it
+                pin=pinned_versions[i] if i < len(pinned_versions) else None,
+                app_options=AppOptions(
+                    app_dir=self.app_dir,
+                    logger=self.log,
+                    core_config=self.core_config,
+                    labextensions_path=self.labextensions_path,
+                ),
+            )
+            for i, arg in enumerate(self.extra_args)
         )
 
 
 class DevelopLabExtensionApp(BaseExtensionApp):
-    description = "Develop labextension"
+    description = "(developer) Develop labextension"
     flags = develop_flags
 
     user = Bool(False, config=True, help="Whether to do a user install")
@@ -246,7 +238,7 @@ class DevelopLabExtensionApp(BaseExtensionApp):
     )
 
     def run_task(self):
-        "Add config for this labextension"
+        """Add config for this labextension"""
         self.extra_args = self.extra_args or [os.getcwd()]
         for arg in self.extra_args:
             develop_labextension_py(
@@ -261,7 +253,7 @@ class DevelopLabExtensionApp(BaseExtensionApp):
 
 
 class BuildLabExtensionApp(BaseExtensionApp):
-    description = "Build labextension"
+    description = "(developer) Build labextension"
 
     static_url = Unicode("", config=True, help="Sets the url for static assets when building")
 
@@ -295,7 +287,7 @@ class BuildLabExtensionApp(BaseExtensionApp):
 
 
 class WatchLabExtensionApp(BaseExtensionApp):
-    description = "Watch labextension"
+    description = "(developer) Watch labextension"
 
     development = Bool(True, config=True, help="Build in development mode")
 
@@ -330,14 +322,16 @@ class UpdateLabExtensionApp(BaseExtensionApp):
     description = "Update labextension(s)"
     flags = update_flags
 
-    all = Bool(False, config=True, help="Whether to update all extensions")
+    all = Bool(False, config=True, help="Whether to update all extensions")  # noqa
 
     def run_task(self):
         self.deprecation_warning(
             "Updating extensions with the jupyter labextension update command is now deprecated and will be removed in a future major version of JupyterLab."
         )
         if not self.all and not self.extra_args:
-            self.log.warn("Specify an extension to update, or use --all to update all extensions")
+            self.log.warning(
+                "Specify an extension to update, or use --all to update all extensions"
+            )
             return False
         app_options = AppOptions(
             app_dir=self.app_dir,
@@ -347,7 +341,7 @@ class UpdateLabExtensionApp(BaseExtensionApp):
         )
         if self.all:
             return update_extension(all_=True, app_options=app_options)
-        return any([update_extension(name=arg, app_options=app_options) for arg in self.extra_args])
+        return any(update_extension(name=arg, app_options=app_options) for arg in self.extra_args)
 
 
 class LinkLabExtensionApp(BaseExtensionApp):
@@ -368,7 +362,7 @@ class LinkLabExtensionApp(BaseExtensionApp):
             labextensions_path=self.labextensions_path,
             core_config=self.core_config,
         )
-        return any([link_package(arg, app_options=options) for arg in self.extra_args])
+        return any(link_package(arg, app_options=options) for arg in self.extra_args)
 
 
 class UnlinkLabExtensionApp(BaseExtensionApp):
@@ -382,14 +376,14 @@ class UnlinkLabExtensionApp(BaseExtensionApp):
             labextensions_path=self.labextensions_path,
             core_config=self.core_config,
         )
-        return any([unlink_package(arg, app_options=options) for arg in self.extra_args])
+        return any(unlink_package(arg, app_options=options) for arg in self.extra_args)
 
 
 class UninstallLabExtensionApp(BaseExtensionApp):
     description = "Uninstall labextension(s) by name"
     flags = uninstall_flags
 
-    all = Bool(False, config=True, help="Whether to uninstall all extensions")
+    all = Bool(False, config=True, help="Whether to uninstall all extensions")  # noqa
 
     def run_task(self):
         self.deprecation_warning(
@@ -404,10 +398,7 @@ class UninstallLabExtensionApp(BaseExtensionApp):
             core_config=self.core_config,
         )
         return any(
-            [
-                uninstall_extension(arg, all_=self.all, app_options=options)
-                for arg in self.extra_args
-            ]
+            uninstall_extension(arg, all_=self.all, app_options=options) for arg in self.extra_args
         )
 
 
@@ -494,13 +485,13 @@ class CheckLabExtensionsApp(BaseExtensionApp):
             self.exit(1)
 
 
-_examples = """
+_EXAMPLES = """
 jupyter labextension list                        # list all configured labextensions
-jupyter labextension develop                     # develop a prebuilt labextension
-jupyter labextension build                       # build a prebuilt labextension
-jupyter labextension watch                       # watch a prebuilt labextension
 jupyter labextension install <extension name>    # install a labextension
 jupyter labextension uninstall <extension name>  # uninstall a labextension
+jupyter labextension develop                     # (developer) develop a prebuilt labextension
+jupyter labextension build                       # (developer) build a prebuilt labextension
+jupyter labextension watch                       # (developer) watch a prebuilt labextension
 """
 
 
@@ -510,26 +501,26 @@ class LabExtensionApp(JupyterApp):
     name = "jupyter labextension"
     version = VERSION
     description = "Work with JupyterLab extensions"
-    examples = _examples
+    examples = _EXAMPLES
 
-    subcommands = dict(
-        install=(InstallLabExtensionApp, "Install labextension(s)"),
-        develop=(DevelopLabExtensionApp, "Develop labextension(s)"),
-        build=(BuildLabExtensionApp, "Build labextension"),
-        watch=(WatchLabExtensionApp, "Watch labextension"),
-        update=(UpdateLabExtensionApp, "Update labextension(s)"),
-        uninstall=(UninstallLabExtensionApp, "Uninstall labextension(s)"),
-        list=(ListLabExtensionsApp, "List labextensions"),
-        link=(LinkLabExtensionApp, "Link labextension(s)"),
-        unlink=(UnlinkLabExtensionApp, "Unlink labextension(s)"),
-        enable=(EnableLabExtensionsApp, "Enable labextension(s)"),
-        disable=(DisableLabExtensionsApp, "Disable labextension(s)"),
-        check=(CheckLabExtensionsApp, "Check labextension(s)"),
-    )
+    subcommands = {
+        "install": (InstallLabExtensionApp, "Install labextension(s)"),
+        "update": (UpdateLabExtensionApp, "Update labextension(s)"),
+        "uninstall": (UninstallLabExtensionApp, "Uninstall labextension(s)"),
+        "list": (ListLabExtensionsApp, "List labextensions"),
+        "link": (LinkLabExtensionApp, "Link labextension(s)"),
+        "unlink": (UnlinkLabExtensionApp, "Unlink labextension(s)"),
+        "enable": (EnableLabExtensionsApp, "Enable labextension(s)"),
+        "disable": (DisableLabExtensionsApp, "Disable labextension(s)"),
+        "check": (CheckLabExtensionsApp, "Check labextension(s)"),
+        "develop": (DevelopLabExtensionApp, "(developer) Develop labextension(s)"),
+        "build": (BuildLabExtensionApp, "(developer) Build labextension"),
+        "watch": (WatchLabExtensionApp, "(developer) Watch labextension"),
+    }
 
     def start(self):
         """Perform the App's functions as configured"""
-        super(LabExtensionApp, self).start()
+        super().start()
 
         # The above should have called a subcommand and raised NoStart; if we
         # get here, it didn't, so we should self.log.info a message.
